import { createApp } from "vue";
import { createStore } from "vuex"
import Util from "./js/Util"
import App from "./App.vue";
import ToggleButton from "./components/ToggleButton.vue"

// Polyfill localstorage with an in-memory solution for old browsers.
// Adapted from https://gist.github.com/juliocesar/926500#gistcomment-1620487
try {
    window.localStorage.setItem("test_localstorage_available", "1");
    window.localStorage.removeItem("test_localstorage_available");
}
catch (error) {
    window.localStorage = {
        _data: {},
        setItem: function (id, val) {
            this._data[id] = String(val);
        },
        getItem: function (id) {
            return Object.prototype.hasOwnProperty.call(this._data, id) ? this._data[id] : undefined;
        },
        removeItem: function (id) {
            return delete this._data[id];
        },
        clear: function () {
            this._data = {};
        }
    };
}

const store = createStore({
    state() {
        return {
            /** @type {Map<String, String>} */
            translations: new Map(),
            macronisedFileInfos: [],
            directInput: null,
            directOutput: []
        }
    },
    mutations: {
        setTranslations(state, translations) {
            state.translations = translations;
        },
        pushFileInfo(state, fileInfo) {
            state.macronisedFileInfos.push({
                id: Util.generateUuid(),
                ...fileInfo
            });
        },
        setDirectInput(state, input) {
            state.directInput = input;
        },
        setDirectOutput(state, output) {
            state.directOutput = output;
        }
    }
});

const app = createApp(App);

app.use(store);
app.component("ToggleButton", ToggleButton)
    .mount("#app");

/* === Get interface translations === */

/** @type {Map<String, String>} */
const translations = new Map();

/* We might be running under Greenstone, so pull the tranlsations from there if so */
/* eslint-disable no-undef */
if (typeof gs !== "undefined" && gs.text && gs.text.atea && gs.text.atea.macroniser) {
    for (const key in gs.text.atea.macroniser) {
        translations.set(key, gs.text.atea.macroniser[key]);
    }

    store.commit("setTranslations", translations)
}
/* eslint-enable no-undef */
else {
    fetch("resources/interface_atea.properties")
        .then(
            async response => {
                const responseText = await response.text();
                const responseTranslations = responseText.split("\n");

                for (const translation of responseTranslations) {
                    const keyvalue = translation.split("=");

                    if (keyvalue.length !== 2) {
                        continue;
                    }

                    const namespace = keyvalue[0].split(".");
                    if (namespace.length !== 3 || namespace[1] !== "macroniser") {
                        continue;
                    }

                    translations.set(namespace[namespace.length - 1], keyvalue[1]);
                }

                store.commit("setTranslations", translations)
            }
        );
}
